#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_scheduler.interfaces.ssh import ISSHCallerTask, ISSHCallerTaskInfo
from pyams_skin.interfaces.viewlet import IToolbarAddingMenu
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import MANAGE_SYSTEM_PERMISSION
from zope.component.interfaces import ISite

# import packages
from pyams_form.form import AJAXAddForm, AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_scheduler.ssh import SSHCallerTask
from pyams_scheduler.zmi.scheduler import SchedulerTasksTable
from pyams_scheduler.zmi.task import TaskBaseAddForm
from pyams_skin.viewlet.toolbar import ToolbarMenuItem
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_scheduler import _


@viewlet_config(name='add-scheduler-ssh-task.menu', context=ISite, layer=IPyAMSLayer,
                view=SchedulerTasksTable, manager=IToolbarAddingMenu,
                permission=MANAGE_SYSTEM_PERMISSION, weight=5)
class SSHTaskAddMenu(ToolbarMenuItem):
    """SSH caller task add menu"""

    label = _("Add SSH command...")
    label_css_class = 'fa fa-fw fa-key'
    url = 'add-scheduler-ssh-task.html'
    modal_target = True


@pagelet_config(name='add-scheduler-ssh-task.html', context=ISite, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
class SSHTaskAddForm(TaskBaseAddForm):
    """SSH command task add form"""

    legend = _("Add SSH command task")
    icon_css_class = 'fa fa-fw fa-key'

    ajax_handler = 'add-scheduler-ssh-task.json'
    task_factory = SSHCallerTask


@view_config(name='add-scheduler-ssh-task.json', context=ISite, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class SSHTaskAJAXAddForm(AJAXAddForm, SSHTaskAddForm):
    """SSH command task add form, AJAX view"""


@pagelet_config(name='settings.html', context=ISSHCallerTask, layer=IPyAMSLayer, permission=MANAGE_SYSTEM_PERMISSION)
class SSHTaskEditForm(AdminDialogEditForm):
    """SSH command task edit form"""

    prefix = 'ssh_settings.'

    @property
    def title(self):
        translate = self.request.localizer.translate
        return translate(_("Scheduler task: {0}")).format(self.context.name)

    legend = _("Edit task settings")
    icon_css_class = 'fa fa-fw fa-key'
    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'

    fields = field.Fields(ISSHCallerTaskInfo)
    ajax_handler = 'settings.json'
    edit_permission = MANAGE_SYSTEM_PERMISSION


@view_config(name='settings.json', context=ISSHCallerTask, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class SSHTaskAJAXEditForm(AJAXEditForm, SSHTaskEditForm):
    """SSH command task edit form, AJAX view"""
